IButton class

Inheritance
Implementers

Constructors

IButton({Key? key, required bool enableAnimation, Color buttonColor = neuDefault1, Color shadowColor = neuShadow, Color borderColor = neuBlack, GestureTapCallback? onPressed, BorderRadius? borderRadius, Offset offset = neuOffset, double buttonHeight = 50, double buttonWidth = 50, double shadowBlurRadius = neuShadowBlurRadius, double borderWidth = neuBorder, int animationDuration = 100, required Widget? child})
A customizable neubrutalist-style button.
const

Properties

animationDuration int
animationDuration (optional) : An Int. defining the Animation Duration in milliseconds.
final
borderColor Color
final
borderRadius BorderRadius?
  • borderRadius (optional) : A BorderRadiusGeometry that defines the border radius of the button.
  • final
    borderWidth double
  • borderWidth (optional) : A double value that defines the width of the button's border.
  • final
    buttonColor Color
  • buttonColor (optional) : A Color that defines the color of the button.
  • final
    buttonHeight double
  • buttonHeight (optional) : A double value that defines the height of the button.
  • final
    buttonWidth double
  • buttonWidth (optional) : A double value that defines the width of the button.
  • final
    child Widget?
  • child: The child widget inside of the button
  • final
    enableAnimation bool
    animate (required) : Boolean Property to toggle the Animation property of the Button Widget.
    final
    hashCode int
    The hash code for this object.
    no setterinherited
    key Key?
    Controls how one widget replaces another widget in the tree.
    finalinherited
    offset Offset
  • offset : An Offset that defines the amount and direction of the blur applied to the shadow of the card.
  • final
    onPressed GestureTapCallback?
  • onPressed (optional) : A callback function that is called when the button is pressed.
  • final
    runtimeType Type
    A representation of the runtime type of the object.
    no setterinherited
    shadowBlurRadius double
  • shadowBlurRadius (optional) : A double that defines the radius of the blur applied to the shadow of the card.
  • final
    shadowColor Color
    shadowColor (optional) : A Color that defines the color of the button's shadow.
    final

    Methods

    createElement() StatefulElement
    Creates a StatefulElement to manage this widget's location in the tree.
    inherited
    createState() State<IButton>
    Creates the mutable state for this widget at a given location in the tree.
    override
    debugDescribeChildren() List<DiagnosticsNode>
    Returns a list of DiagnosticsNode objects describing this node's children.
    inherited
    debugFillProperties(DiagnosticPropertiesBuilder properties) → void
    Add additional properties associated with the node.
    inherited
    noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
    Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
    inherited
    toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
    A string representation of this object.
    inherited
    toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
    Returns a string representation of this node and its descendants.
    inherited
    toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
    Returns a one-line detailed description of the object.
    inherited
    toStringShort() String
    A short, textual description of this widget.
    inherited

    Operators

    operator ==(Object other) bool
    The equality operator.
    inherited