borderRadius property
- borderRadius (optional) : A BorderRadiusGeometry that defines the border radius of the button.
If not specified, the button will have a circular border radius.
Implementation
final BorderRadius? borderRadius;
If not specified, the button will have a circular border radius.
final BorderRadius? borderRadius;