menu
flutter_button_three_d package
documentation
widgets/button.dart
IButton
offset property
offset property
dark_mode
light_mode
offset
property
Offset
offset
final
offset : An Offset that defines the amount and direction of the blur applied to the shadow of the card.
Implementation
final Offset offset;
flutter_button_three_d package
documentation
widgets/button
IButton
offset property
IButton class