NeuContainer class

Inheritance

Constructors

NeuContainer({Key? key, Offset offset = neuOffset, Color? color = neuDefault1, Color shadowColor = neuShadow, Color borderColor = neuBlack, double? height, double? width, double borderWidth = neuBorder, double shadowBlurRadius = neuShadowBlurRadius, BlurStyle shadowBlurStyle = neuBlurStyle, Widget? child, BorderRadiusGeometry? borderRadius})
A customizable neubrutalist-style Container Template, allowing user to experiment freely without any restriction in functionality.
const

Properties

borderColor Color
  • borderColor (optional): A Color that defines the color of the border of the container.
  • final
    borderRadius BorderRadiusGeometry?
  • borderRadius (optional): A BorderRadiusGeometry that defines the radius of the corners of the container.
  • final
    borderWidth double
  • borderWidth (optional): A double that defines the width of the border of the container.
  • final
    child Widget?
  • child (optional): A widget that is displayed inside the container.
  • final
    color Color?
  • color (optional): A Color that defines the background color of the container.
  • final
    hashCode int
    The hash code for this object.
    no setterinherited
    height double?
  • height (optional): A double that defines the height of the container.
  • final
    key Key?
    Controls how one widget replaces another widget in the tree.
    finalinherited
    offset Offset
  • offset (optional): An Offset that defines the position of the shadow of the container.
  • final
    runtimeType Type
    A representation of the runtime type of the object.
    no setterinherited
    shadowBlurRadius double
  • shadowBlurRadius (optional): A double that defines the blur radius of the shadow of the container.
  • final
    shadowBlurStyle BlurStyle
  • shadowBlurStyle (optional): A BlurStyle that defines the style of the blur of the shadow of the container.
  • final
    shadowColor Color
  • shadowColor (optional): A Color that defines the color of the shadow of the container.
  • final
    width double?
  • width (optional): A double that defines the width of the container.
  • final

    Methods

    createElement() StatefulElement
    Creates a StatefulElement to manage this widget's location in the tree.
    inherited
    createState() State<NeuContainer>
    Creates the mutable state for this widget at a given location in the tree.
    override
    debugDescribeChildren() List<DiagnosticsNode>
    Returns a list of DiagnosticsNode objects describing this node's children.
    inherited
    debugFillProperties(DiagnosticPropertiesBuilder properties) → void
    Add additional properties associated with the node.
    inherited
    noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
    Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
    inherited
    toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
    A string representation of this object.
    inherited
    toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
    Returns a string representation of this node and its descendants.
    inherited
    toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
    Returns a one-line detailed description of the object.
    inherited
    toStringShort() String
    A short, textual description of this widget.
    inherited

    Operators

    operator ==(Object other) bool
    The equality operator.
    inherited