NeuContainer class
Constructors
-
NeuContainer({Key? key, Offset offset = neuOffset, Color? color = neuDefault1, Color shadowColor = neuShadow, Color borderColor = neuBlack, double? height, double? width, double borderWidth = neuBorder, double shadowBlurRadius = neuShadowBlurRadius, BlurStyle shadowBlurStyle = neuBlurStyle, Widget? child, BorderRadiusGeometry? borderRadius})
-
A customizable neubrutalist-style Container Template, allowing
user to experiment freely without any restriction in functionality.
const
Properties
-
borderColor
→ Color
-
- borderColor (optional): A Color that defines the color of the border of the container.
final
-
borderRadius
→ BorderRadiusGeometry?
-
- borderRadius (optional): A BorderRadiusGeometry that defines the radius of the corners of the container.
final
-
borderWidth
→ double
-
- borderWidth (optional): A double that defines the width of the border of the container.
final
-
child
→ Widget?
-
- child (optional): A widget that is displayed inside the container.
final
-
color
→ Color?
-
- color (optional): A Color that defines the background color of the container.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
height
→ double?
-
- height (optional): A double that defines the height of the container.
final
-
key
→ Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
offset
→ Offset
-
- offset (optional): An Offset that defines the position of the shadow of the container.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
shadowBlurRadius
→ double
-
- shadowBlurRadius (optional): A double that defines the blur radius of the shadow of the container.
final
-
shadowBlurStyle
→ BlurStyle
-
- shadowBlurStyle (optional): A BlurStyle that defines the style of the blur of the shadow of the container.
final
-
shadowColor
→ Color
-
- shadowColor (optional): A Color that defines the color of the shadow of the container.
final
-
width
→ double?
-
- width (optional): A double that defines the width of the container.
final