FlutterTextButton3D class
Constructors
-
FlutterTextButton3D({Key? key, required dynamic enableAnimation, required Text text, int animationDuration = 100, Color borderColor = neuBlack, BorderRadius? borderRadius, double borderWidth = neuBorder, Color buttonColor = neuDefault1, double buttonHeight = 50, double buttonWidth = 100, Offset offset = neuOffset, GestureTapCallback? onPressed, double shadowBlurRadius = neuShadowBlurRadius, Color shadowColor = neuShadow})
-
A customizable neubrutalist-style text button.
const
Properties
-
animationDuration
→ int
-
animationDuration (optional) : An Int. defining the Animation Duration in milliseconds.
finalinherited
-
borderColor
→ Color
-
finalinherited
-
borderRadius
→ BorderRadius?
-
- borderRadius (optional) : A BorderRadiusGeometry that defines the border radius of the button.
finalinherited
-
borderWidth
→ double
-
- borderWidth (optional) : A double value that defines the width of the button's border.
finalinherited
-
buttonColor
→ Color
-
- buttonColor (optional) : A Color that defines the color of the button.
finalinherited
-
buttonHeight
→ double
-
- buttonHeight (optional) : A double value that defines the height of the button.
finalinherited
-
buttonWidth
→ double
-
- buttonWidth (optional) : A double value that defines the width of the button.
finalinherited
-
child
→ Widget?
-
- child: The child widget inside of the button
finalinherited
-
enableAnimation
→ bool
-
animate (required) : Boolean Property to toggle the Animation property of the Button Widget.
finalinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
key
→ Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
offset
→ Offset
-
- offset : An Offset that defines the amount and direction of the blur applied to the shadow of the card.
finalinherited
-
onPressed
→ GestureTapCallback?
-
- onPressed (optional) : A callback function that is called when the button is pressed.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
shadowBlurRadius
→ double
-
- shadowBlurRadius (optional) : A double that defines the radius of the blur applied to the shadow of the card.
finalinherited
-
shadowColor
→ Color
-
shadowColor (optional) : A Color that defines the color of the button's shadow.
finalinherited
-
text
→ Text
-
This Property helps to insert a Text Widget and Customize it according to your need
final